##########
About GWpy
##########

.. toctree::
    :maxdepth: 1
    :caption: Project Information

    citing
    license
    changelog

.. toctree::
    :maxdepth: 1
    :caption: Developer Information

    contributing
    dev/release
